/**
 * Check whether any members of an array pass a check
 * @param target array to evaluate
 * @param predicate check to perform
 * @public
 */
export declare function some<T>(target: T[], predicate: (val: T) => boolean): boolean;
/**
 * Check whether all members of an array pass a check
 * @param target array to evaluate
 * @param predicate check to perform
 * @public
 */
export declare function all<T>(target: T[], predicate: (val: T) => boolean): boolean;
/**
 * Check to see whether a value is an array
 * @param value value to check
 * @public
 */
export declare function isArray(value: any): value is any[];
export declare function isArray<T>(value?: T[]): value is T[];
/**
 * Check to see if a value is a homogenous array
 * @param value value to check
 * @param validator validator to apply to each member of the collection
 * @public
 */
export declare function isHomogenousArray<T>(value: any[], validator: (v: any) => boolean): value is T[];
/**
 * Invoke a callback for each member of an array
 *
 * @param array array to iterate over
 * @param callback callback to invoke for each member of the array
 * @public
 */
export declare function forEach<T>(array: T[] | ReadonlyArray<T> | undefined, callback: (item: T, idx: number) => void): void;
//# sourceMappingURL=array.d.ts.map